@@ -26,7 +26,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: asmdef.h 2191 2010-11-05 13:45:57Z arcanum $	*/
+/* $Id$	*/
 
 #ifndef	_ASMDEF_H
 #define _ASMDEF_H
@@ -206,6 +206,25 @@ _U(\name):
 #endif
 .endm
 
+/* Macro 'X_sbiw' extends SBIW instruction for AVR_TINY chips. */
+.macro	X_sbiw	dst,val
+#if !defined (__AVR_TINY__)
+	sbiw	\dst,\val
+#else
+  REGNO	.L__sbiw_dst, \dst
+  .if	.L__sbiw_dst < 0
+    .exitm
+  .endif
+  .if	.L__sbiw_dst % 1
+    .err	; Invalid register arg in X_sbiw macro.
+    .exitm
+  .endif
+
+	subi	.L__sbiw_dst, \val
+	sbci	.L__sbiw_dst + 1, 0
+#endif /* AVR_TINY */
+.endm
+
 /* Macro 'X_lpm' extends enhanced lpm instruction for classic chips.
    Usage:
 	X_lpm	reg, dst
@@ -275,4 +294,15 @@ _U(\name):
   .endif
 .endm
 
+#ifndef HAVE_TINY_WEAK_ALIAS
+#define HAVE_TINY_WEAK_ALIAS
+.macro TINY_WEAK_ALIAS new old
+#ifdef __AVR_TINY__
+    .weak \new
+    .type \new, @function
+    \new = \old
+#endif /* __AVR_TINY__ */
+.endm
+#endif /* !HAVE_TINY_WEAK_ALIAS */
+
 #endif	/* !_ASMDEF_H */
