@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io43u32x.h 1873 2009-02-11 17:53:39Z arcanum $ */
+/* $Id$ */
 
 /* avr/io43u32x.h - definitions for AT43USB32x */
 
@@ -425,6 +425,7 @@
 #define    TXB8         0
 
 /* Constants */
+#define    RAMSTART 0x60
 #define    RAMEND   0x025F     /*Last On-Chip SRAM Location*/
 #define    XRAMEND  RAMEND
 #define    E2END    0x0000
@@ -433,4 +434,8 @@
    but no RAMPZ causes gcrt1.S build to fail, so assume 64K for now...  */
 #define    FLASHEND 0x0FFFF
 
+#define SLEEP_MODE_IDLE         0
+#define SLEEP_MODE_PWR_DOWN     _BV(SM)
+
+
 #endif /* _AVR_43USB32X_H_ */
