@@ -29,7 +29,7 @@
   POSSIBILITY OF SUCH DAMAGE. 
 */
 
-/* $Id: io90pwm2b.h 2225 2011-03-02 16:27:26Z arcanum $ */
+/* $Id$ */
 
 /* avr/io90pwm2b.h - definitions for AT90PWM2B */
 
@@ -409,6 +409,16 @@
 #define PRPSC1 6
 #define PRPSC2 7
 
+#define __AVR_HAVE_PRR	((1<<PRADC)|(1<<PRUSART0)|(1<<PRSPI)|(1<<PRTIM0)|(1<<PRTIM1)|(1<<PRPSC0)|(1<<PRPSC1)|(1<<PRPSC2))
+#define __AVR_HAVE_PRR_PRADC
+#define __AVR_HAVE_PRR_PRUSART0
+#define __AVR_HAVE_PRR_PRSPI
+#define __AVR_HAVE_PRR_PRTIM0
+#define __AVR_HAVE_PRR_PRTIM1
+#define __AVR_HAVE_PRR_PRPSC0
+#define __AVR_HAVE_PRR_PRPSC1
+#define __AVR_HAVE_PRR_PRPSC2
+
 #define OSCCAL _SFR_MEM8(0x66)
 #define CAL0 0
 #define CAL1 1
@@ -1387,6 +1397,7 @@
 
 
 /* Memory Sizes */
+#define RAMSTART       0x100
 #define RAMEND         0x2FF
 #define XRAMSIZE       0
 #define XRAMEND        RAMEND
@@ -1448,4 +1459,10 @@
 #define SIGNATURE_2 0x83
 
 
+#define SLEEP_MODE_IDLE (0x00<<1)
+#define SLEEP_MODE_ADC (0x01<<1)
+#define SLEEP_MODE_PWR_DOWN (0x02<<1)
+#define SLEEP_MODE_STANDBY (0x06<<1)
+
+
 #endif /* _AVR_IO90PWM2B_H_ */
