@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom16a.h 2248 2011-05-23 19:54:32Z joerg_wunsch $ */
+/* $Id$ */
 
 /* avr/iom16a.h - definitions for ATmega16A */
 
@@ -676,8 +676,10 @@
 #define TIMER1_OVF_vect      _VECTOR(8)  /* Timer/Counter1 Overflow */
 #define TIMER0_OVF_vect_num  9
 #define TIMER0_OVF_vect      _VECTOR(9)  /* Timer/Counter0 Overflow */
+#define SPI_STC_vect_num  10
+#define SPI_STC_vect      _VECTOR(10)  /* Serial Transfer Complete */
 #define SPISTC_vect_num  10
-#define SPISTC_vect      _VECTOR(10)  /* Serial Transfer Complete */
+#define SPISTC_vect      _VECTOR(10)  /* Keep for backward-compatibility */
 
 /* The following vectors use an inconsistent (to the ATmega16 etc.)
    naming scheme.  The inconsistent names are preserved here for softwares
@@ -912,5 +914,13 @@
 #define SS_PIN   PINB
 #define SS_BIT   4
 
+
+#define SLEEP_MODE_IDLE (0x00<<4)
+#define SLEEP_MODE_ADC (0x01<<4)
+#define SLEEP_MODE_PWR_DOWN (0x02<<4)
+#define SLEEP_MODE_PWR_SAVE (0x03<<4)
+#define SLEEP_MODE_STANDBY (0x0A<<4)
+#define SLEEP_MODE_EXT_STANDBY (0x0B<<4)
+
 #endif /* _AVR_ATmega16A_H_ */
 
