@@ -1,4 +1,4 @@
-/* Copyright (c) 2009 Atmel Corporation
+/* Copyright (c) 2009, 2011 Atmel Corporation
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -28,9 +28,9 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom16hvb.h 2086 2009-12-15 03:24:16Z arcanum $ */
+/* $Id$ */
 
-/* avr/iom16hvb.h - definitions for ATmega16HVB */
+/* avr/iom16hvbrevb.h - definitions for ATmega16HVB revision B */
 
 /* This file should only be included from <avr/io.h>, never directly. */
 
@@ -39,14 +39,14 @@
 #endif
 
 #ifndef _AVR_IOXXX_H_
-#  define _AVR_IOXXX_H_ "iom16hvb.h"
+#  define _AVR_IOXXX_H_ "iom16hvbrevb.h"
 #else
 #  error "Attempt to include more than one <avr/ioXXX.h> file."
 #endif 
 
 
-#ifndef _AVR_ATmega16HVB_H_
-#define _AVR_ATmega16HVB_H_ 1
+#ifndef _AVR_ATmega16HVBREVB_H_
+#define _AVR_ATmega16HVBREVB_H_ 1
 
 
 /* Registers and associated bit numbers. */
@@ -349,6 +349,14 @@
 #define PRVRM 5
 #define PRTWI 6
 
+#define __AVR_HAVE_PRR0	((1<<PRVADC)|(1<<PRTIM0)|(1<<PRTIM1)|(1<<PRSPI)|(1<<PRVRM)|(1<<PRTWI))
+#define __AVR_HAVE_PRR0_PRVADC
+#define __AVR_HAVE_PRR0_PRTIM0
+#define __AVR_HAVE_PRR0_PRTIM1
+#define __AVR_HAVE_PRR0_PRSPI
+#define __AVR_HAVE_PRR0_PRVRM
+#define __AVR_HAVE_PRR0_PRTWI
+
 #define FOSCCAL _SFR_MEM8(0x66)
 #define FCAL0 0
 #define FCAL1 1
@@ -1035,5 +1043,11 @@
 #define OC_PIN   PINOC
 #define OC_BIT   OC
 
-#endif /* _AVR_ATmega16HVB_H_ */
+
+#define SLEEP_MODE_IDLE (0x00<<1)
+#define SLEEP_MODE_ADC (0x01<<1)
+#define SLEEP_MODE_PWR_SAVE (0x03<<1)
+#define SLEEP_MODE_PWR_OFF (0x04<<1)
+
+#endif /* _AVR_ATmega16HVBREVB_H_ */
 
