@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iomxxhva.h 2225 2011-03-02 16:27:26Z arcanum $ */
+/* $Id$ */
 
 /* iomxxhva.h - definitions for ATmega8HVA and ATmega16HVA.  */
 
@@ -252,6 +252,13 @@
 #define PRTIM0  1
 #define PRVADC  0
 
+#define __AVR_HAVE_PRR0	((1<<PRVADC)|(1<<PRTIM0)|(1<<PRTIM1)|(1<<PRSPI)|(1<<PRVRM))
+#define __AVR_HAVE_PRR0_PRVADC
+#define __AVR_HAVE_PRR0_PRTIM0
+#define __AVR_HAVE_PRR0_PRTIM1
+#define __AVR_HAVE_PRR0_PRSPI
+#define __AVR_HAVE_PRR0_PRVRM
+
 /* Reserved [0x65] */
 
 #define FOSCCAL _SFR_MEM8(0x66)
