@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotn461a.h,v 1.1.2.2 2009/11/18 22:06:28 arcanum Exp $ */
+/* $Id$ */
 
 /* avr/iotn461a.h - definitions for ATtiny461A */
 
@@ -556,6 +556,12 @@
 #define PRTIM0 2
 #define PRTIM1 3
 
+#define __AVR_HAVE_PRR	((1<<PRADC)|(1<<PRUSI)|(1<<PRTIM0)|(1<<PRTIM1))
+#define __AVR_HAVE_PRR_PRADC
+#define __AVR_HAVE_PRR_PRUSI
+#define __AVR_HAVE_PRR_PRTIM0
+#define __AVR_HAVE_PRR_PRTIM1
+
 #define SPMCSR _SFR_IO8(0x37)
 #define SPMEN 0
 #define PGERS 1
@@ -972,5 +978,11 @@
 #define PA0_PIN   PINADC
 #define PA0_BIT   ADC0
 
+
+#define SLEEP_MODE_IDLE (0x00<<3)
+#define SLEEP_MODE_ADC (0x01<<3)
+#define SLEEP_MODE_PWR_DOWN (0x02<<3)
+#define SLEEP_MODE_STANDBY (0x03<<3)
+
 #endif /* _AVR_ATtiny461A_H_ */
 
