@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: lock.h 1692 2008-04-29 18:07:36Z arcanum $ */
+/* $Id$ */
 
 /* avr/lock.h - Lock Bits API */
 
@@ -184,19 +184,16 @@
 */
 
 
-#ifndef __ASSEMBLER__
+#if !(defined(__ASSEMBLER__) || defined(__DOXYGEN__))
 
 #ifndef LOCKMEM
-#define LOCKMEM  __attribute__((section (".lock")))
+#define LOCKMEM  __attribute__((__used__, __section__ (".lock")))
 #endif
 
 #ifndef LOCKBITS
 #define LOCKBITS unsigned char __lock LOCKMEM
 #endif
 
-#endif  /* !__ASSEMBLER */
-
-
 /* Lock Bit Modes */
 #if defined(__LOCK_BITS_EXIST)
 #define LB_MODE_1  (0xFF)
@@ -233,7 +230,11 @@
 #define BLBB1 ~_BV(7)
 #endif
 
-
+#ifndef LOCKBITS_DEFAULT
 #define LOCKBITS_DEFAULT (0xFF)
+#endif
+
+#endif  /* !(__ASSEMBLER || __DOXYGEN__) */
+
 
 #endif /* _AVR_LOCK_H_ */
