@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: setjmp.h 1656 2008-03-24 11:29:55Z dmix $ */
+/* $Id$ */
 
 #ifndef __SETJMP_H_
 #define __SETJMP_H_ 1
@@ -40,17 +40,20 @@ extern "C" {
 /*
    jmp_buf:
 	offset	size	description
-	 0	16	call-saved registers (r2-r17)
-	16	 2	frame pointer (r29:r28)
-	18	 2	stack pointer (SPH:SPL)
-	20	 1	status register (SREG)
-	21	 2/3	return address (PC) (2 bytes used for <=128Kw flash)
-	23/24 = total size
+	 0	16/2	call-saved registers (r2-r17)
+				(AVR_TINY arch has only 2 call saved registers (r18,r19))
+	16/2	 2	frame pointer (r29:r28)
+	18/4	 2	stack pointer (SPH:SPL)
+	20/6	 1	status register (SREG)
+	21/7	 2/3	return address (PC) (2 bytes used for <=128Kw flash)
+	23/24/9 = total size (AVR_TINY arch always has 2 bytes PC)
  */
 
 #if !defined(__DOXYGEN__)
 
-#if	defined(__AVR_3_BYTE_PC__) && __AVR_3_BYTE_PC__
+#if defined(__AVR_TINY__)
+# define _JBLEN  9
+#elif	defined(__AVR_3_BYTE_PC__) && __AVR_3_BYTE_PC__
 # define _JBLEN  24
 #else
 # define _JBLEN  23
@@ -65,17 +68,17 @@ typedef struct _jmp_buf { unsigned char _jb[_JBLEN]; } jmp_buf[1];
     While the C language has the dreaded \c goto statement, it can only be
     used to jump to a label in the same (local) function.  In order to jump
     directly to another (non-local) function, the C library provides the
-    setjmp() and longjmp() functions.  setjmp() and longjmp() are useful for
+    #setjmp and #longjmp functions.  setjmp and longjmp are useful for
     dealing with errors and interrupts encountered in a low-level subroutine
     of a program.
 
-    \note setjmp() and longjmp() make programs hard to understand and maintain.
+    \note #setjmp and #longjmp make programs hard to understand and maintain.
     If possible, an alternative should be used.
 
-    \note longjmp() can destroy changes made to global register
+    \note longjmp can destroy changes made to global register
     variables (see \ref faq_regbind).
 
-    For a very detailed discussion of setjmp()/longjmp(), see Chapter 7 of
+    For a very detailed discussion of setjmp/longjmp, see Chapter 7 of
     <em>Advanced Programming in the UNIX Environment</em>, by W. Richard
     Stevens.
 
@@ -90,20 +93,18 @@ typedef struct _jmp_buf { unsigned char _jb[_JBLEN]; } jmp_buf[1];
     {
         if (setjmp (env))
         {
-            ... handle error ...
+            // Handle error ...
         }
 
         while (1)
         {
-           ... main processing loop which calls foo() some where ...
+           // Main processing loop which calls foo() somewhere ...
         }
     }
 
-    ...
-
     void foo (void)
     {
-        ... blah, blah, blah ...
+        // blah, blah, blah ...
 
         if (err)
         {
@@ -112,9 +113,11 @@ typedef struct _jmp_buf { unsigned char _jb[_JBLEN]; } jmp_buf[1];
     }
     \endcode */
 
+#ifndef __DOXYGEN__
 #ifndef __ATTR_NORETURN__
 #define __ATTR_NORETURN__ __attribute__((__noreturn__))
 #endif
+#endif /* ! DOXYGEN */
 
 /** \ingroup setjmp
     \brief Save stack context for non-local goto.
