@@ -33,7 +33,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
 
-  $Id: stdio.h,v 1.29.2.1 2008/02/23 08:59:27 dmix Exp $
+  $Id$
 */
 
 #ifndef _STDIO_H_
@@ -44,9 +44,11 @@
 #include <inttypes.h>
 #include <stdarg.h>
 
+#ifndef __DOXYGEN__
 #define __need_NULL
 #define __need_size_t
 #include <stddef.h>
+#endif	/* !__DOXYGEN__ */
 
 /** \file */
 /** \defgroup avr_stdio <stdio.h>: Standard IO facilities
@@ -55,7 +57,7 @@
     <h3>Introduction to the Standard IO facilities</h3>
 
     This file declares the standard IO facilities that are implemented
-    in \c avr-libc.  Due to the nature of the underlying hardware,
+    in AVR-LibC.  Due to the nature of the underlying hardware,
     only a limited subset of standard IO is implemented.  There is no
     actual file implementation available, so only device IO can be
     performed.  Since there's no operating system, the application
@@ -72,7 +74,7 @@
     Also, they are not fast due to the nature of interpreting the
     format string at run-time.  Whenever possible, resorting to the
     (sometimes non-standard) predetermined conversion facilities that are
-    offered by avr-libc will usually cost much less in terms of speed
+    offered by AVR-LibC will usually cost much less in terms of speed
     and code size.
 
     <h3>Tunable options for code size vs. feature set</h3>
@@ -86,16 +88,16 @@
     <h3>Outline of the chosen API</h3>
 
     The standard streams \c stdin, \c stdout, and \c stderr are
-    provided, but contrary to the C standard, since avr-libc has no
+    provided, but contrary to the C standard, since AVR-LibC has no
     knowledge about applicable devices, these streams are not already
     pre-initialized at application startup.  Also, since there is no
-    notion of "file" whatsoever to avr-libc, there is no function
+    notion of "file" whatsoever to AVR-LibC, there is no function
     \c fopen() that could be used to associate a stream to some device.
     (See \ref stdio_note1 "note 1".)  Instead, the function \c fdevopen()
     is provided to associate a stream to a device, where the device
     needs to provide a function to send a character, to receive a
     character, or both.  There is no differentiation between "text" and
-    "binary" streams inside avr-libc.  Character \c \\n is sent
+    "binary" streams inside AVR-LibC.  Character \c \\n is sent
     literally down to the device's \c put() function.  If the device
     requires a carriage return (\c \\r) character to be sent before
     the linefeed, its \c put() routine must implement this (see
@@ -134,7 +136,7 @@
     standard name, where the format string is expected to be in
     SRAM, as well as a version with the suffix "_P" where the format
     string is expected to reside in the flash ROM.  The macro
-    \c PSTR (explained in \ref avr_pgmspace) becomes very handy
+    #PSTR (explained in \ref avr_pgmspace) becomes very handy
     for declaring these format strings.
 
     \anchor stdio_without_malloc
@@ -192,14 +194,17 @@
 
     <h3>Notes</h3>
 
-    \anchor stdio_note1 \par Note 1:
+<dl>
+<dt>\anchor stdio_note1 Note 1:</dt>
+<dd>    
     It might have been possible to implement a device abstraction that
     is compatible with \c fopen() but since this would have required
     to parse a string, and to take all the information needed either
     out of this string, or out of an additional table that would need to be
     provided by the application, this approach was not taken.
-
-    \anchor stdio_note2 \par Note 2:
+</dd>
+<dt>\anchor stdio_note2 Note 2:</dt>
+<dd>
     This basically follows the Unix approach: if a device such as a
     terminal needs special handling, it is in the domain of the
     terminal device driver to provide this functionality.  Thus, a
@@ -212,14 +217,15 @@
     {
 
       if (c == '\n')
-        uart_putchar('\r');
+        uart_putchar('\r', stream);
       loop_until_bit_is_set(UCSRA, UDRE);
       UDR = c;
       return 0;
     }
     \endcode
-
-    \anchor stdio_note3 \par Note 3:
+</dd>
+<dt>\anchor stdio_note3 Note 3:</dt>
+<dd>
     This implementation has been chosen because the cost of maintaining
     an alias is considerably smaller than the cost of maintaining full
     copies of each stream.  Yet, providing an implementation that offers
@@ -229,7 +235,9 @@
     arguments of variadic functions on the stack (as opposed to passing
     them in registers for functions that take a fixed number of
     parameters), the ability to pass one parameter less by implying
-    \c stdin will also save some execution time.
+    \c stdin or stdout will also save some execution time.
+</dd>
+</dl>
 */
 
 #if !defined(__DOXYGEN__)
@@ -267,12 +275,12 @@ struct __file {
 
 #endif /* not __DOXYGEN__ */
 
-/*@{*/
+/**@{*/
 /**
    \c FILE is the opaque structure that is passed around between the
    various standard IO functions.
 */
-#define FILE	struct __file
+typedef struct __file FILE;
 
 /**
    Stream that will be used as an input stream by the simplified
@@ -329,13 +337,13 @@ struct __file {
    This macro takes a user-supplied buffer \c stream, and sets it up
    as a stream that is valid for stdio operations, similar to one that
    has been obtained dynamically from fdevopen(). The buffer to setup
-   must be of type FILE.
+   must be of type #FILE.
 
    The arguments \c put and \c get are identical to those that need to
    be passed to fdevopen().
 
-   The \c rwflag argument can take one of the values _FDEV_SETUP_READ,
-   _FDEV_SETUP_WRITE, or _FDEV_SETUP_RW, for read, write, or read/write
+   The \c rwflag argument can take one of the values #_FDEV_SETUP_READ,
+   #_FDEV_SETUP_WRITE, or #_FDEV_SETUP_RW, for read, write, or read/write
    intent, respectively.
 
    \note No assignments to the standard streams will be performed by
@@ -384,13 +392,20 @@ struct __file {
  */
 #define FDEV_SETUP_STREAM(put, get, rwflag)
 #else  /* !DOXYGEN */
-#define FDEV_SETUP_STREAM(p, g, f) \
-	{ \
-		.put = p, \
-		.get = g, \
-		.flags = f, \
-		.udata = 0, \
-	}
+/* In order to work with C++, we have to mention the fields in the order
+   as they appear in struct __file.  Also, designated initializers are
+   only supported since C++20.  */
+#define FDEV_SETUP_STREAM(PU, GE, FL) \
+    {                                 \
+        (char*) 0  /* buf */,         \
+        0u         /* unget */,       \
+        FL         /* flags */,       \
+        0          /* size */,        \
+        0          /* len */,         \
+        PU         /* put */,         \
+        GE         /* get */,         \
+        (void*) 0  /* udata */        \
+    }
 #endif /* DOXYGEN */
 
 #ifdef __cplusplus
@@ -407,13 +422,13 @@ extern struct __file *__iob[];
 #if defined(__STDIO_FDEVOPEN_COMPAT_12)
 /*
  * Declare prototype for the discontinued version of fdevopen() that
- * has been in use up to avr-libc 1.2.x.  The new implementation has
+ * has been in use up to AVR-LibC 1.2.x.  The new implementation has
  * some backwards compatibility with the old version.
  */
 extern FILE *fdevopen(int (*__put)(char), int (*__get)(void),
                       int __opts __attribute__((unused)));
 #else  /* !defined(__STDIO_FDEVOPEN_COMPAT_12) */
-/* New prototype for avr-libc 1.4 and above. */
+/* New prototype for AVR-LibC 1.4 and above. */
 extern FILE *fdevopen(int (*__put)(char, FILE*), int (*__get)(FILE*));
 #endif /* defined(__STDIO_FDEVOPEN_COMPAT_12) */
 
@@ -491,7 +506,7 @@ extern int	fclose(FILE *__stream);
             signed conversion.  A + overrides a space if both are
             used.</li>
       </ul>
-      
+
    -   An optional decimal digit string specifying a minimum field width.
        If the converted value has fewer characters than the field width, it
        will be padded with spaces on the left (or right, if the left-adjustment
@@ -534,7 +549,7 @@ extern int	fclose(FILE *__stream);
    - \c %  A \c % is written.  No argument is converted.  The complete
            conversion specification is "%%".
    - \c eE The double argument is rounded and converted in the format
-           \c "[-]d.dddedd" where there is one digit before the
+           \c "[-]d.ddde±dd" where there is one digit before the
            decimal-point character and the number of digits after it
            is equal to the precision; if the precision is missing, it
            is taken as 6; if the precision is zero, no decimal-point
@@ -592,7 +607,7 @@ extern int	fclose(FILE *__stream);
    \par Notes:
    - For floating-point conversions, if you link default or minimized
      version of vfprintf(), the symbol \c ? will be output and double
-     argument will be skiped. So you output below will not be crashed.
+     argument will be skipped. So you output below will not be crashed.
      For default version the width field and the "pad to left" ( symbol
      minus ) option will work in this case.
    - The \c hh length modifier is ignored (\c char argument is
@@ -633,7 +648,7 @@ extern int	putchar(int __c);
 /**
    The macro \c putc used to be a "fast" macro implementation with a
    functionality identical to fputc().  For space constraints, in
-   \c avr-libc, it is just an alias for \c fputc.
+   AVR-LibC, it is just an alias for \c fputc.
 */
 #define putc(__c, __stream) fputc(__c, __stream)
 
@@ -644,7 +659,7 @@ extern int	putchar(int __c);
 
 /**
    The function \c printf performs formatted output to stream
-   \c stderr.  See \c vfprintf() for details.
+   \c stdout.  See \c vfprintf() for details.
 */
 extern int	printf(const char *__fmt, ...);
 
@@ -783,7 +798,7 @@ extern int	getchar(void);
 /**
    The macro \c getc used to be a "fast" macro implementation with a
    functionality identical to fgetc().  For space constraints, in
-   \c avr-libc, it is just an alias for \c fgetc.
+   AVR-LibC, it is just an alias for \c fgetc.
 */
 #define getc(__stream) fgetc(__stream)
 
@@ -801,7 +816,7 @@ extern int	getchar(void);
 
    Currently, only a single character can be pushed back onto the
    stream.
-   
+
    The ungetc() function returns the character pushed back after the
    conversion, or \c EOF if the operation fails.  If the value of the
    argument \c c character equals \c EOF, the operation will fail and
@@ -941,14 +956,38 @@ static __inline__ int fflush(FILE *stream __attribute__((unused)))
 }
 #endif
 
+#ifndef __DOXYGEN__
+/* only mentioned for libstdc++ support, not implemented in library */
+#define BUFSIZ 1024
+#define _IONBF 0
+__extension__ typedef long long fpos_t;
+extern int fgetpos(FILE *stream, fpos_t *pos);
+extern FILE *fopen(const char *path, const char *mode);
+extern FILE *freopen(const char *path, const char *mode, FILE *stream);
+extern FILE *fdopen(int, const char *);
+extern int fseek(FILE *stream, long offset, int whence);
+extern int fsetpos(FILE *stream, fpos_t *pos);
+extern long ftell(FILE *stream);
+extern int fileno(FILE *);
+extern void perror(const char *s);
+extern int remove(const char *pathname);
+extern int rename(const char *oldpath, const char *newpath);
+extern void rewind(FILE *stream);
+extern void setbuf(FILE *stream, char *buf);
+extern int setvbuf(FILE *stream, char *buf, int mode, size_t size);
+extern FILE *tmpfile(void);
+extern char *tmpnam (char *s);
+#endif	/* !__DOXYGEN__ */
+
 #ifdef __cplusplus
 }
 #endif
 
-/*@}*/
+/**@}*/
 
+#ifndef __DOXYGEN__
 /*
- * The following constants are currently not used by avr-libc's
+ * The following constants are currently not used by AVR-LibC's
  * stdio subsystem.  They are defined here since the gcc build
  * environment expects them to be here.
  */
@@ -956,6 +995,8 @@ static __inline__ int fflush(FILE *stream __attribute__((unused)))
 #define SEEK_CUR 1
 #define SEEK_END 2
 
+#endif
+
 #endif /* __ASSEMBLER */
 
-#endif /* _STDLIB_H_ */
+#endif /* _STDIO_H_ */
