@@ -1,5 +1,7 @@
 /* Copyright (c) 2002, 2003, 2004  Marek Michalkiewicz
    Copyright (c) 2005, 2007 Joerg Wunsch
+   Copyright (c) 2013 Dave Hylands
+   Copyright (c) 2013 Frederic Nadeau
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -29,13 +31,19 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: crc16.h 2136 2010-06-08 12:03:38Z joerg_wunsch $ */
+/* $Id$ */
 
 #ifndef _UTIL_CRC16_H_
 #define _UTIL_CRC16_H_
 
 #include <stdint.h>
 
+#ifndef __DOXYGEN__
+#ifndef __ATTR_ALWAYS_INLINE__
+#define __ATTR_ALWAYS_INLINE__ __inline__ __attribute__((__always_inline__))
+#endif
+#endif /* ! DOXYGEN */
+
 /** \file */
 /** \defgroup util_crc <util/crc16.h>: CRC Computations
     \code#include <util/crc16.h>\endcode
@@ -65,14 +73,14 @@
     uint8_t serno[] = { 0x02, 0x1c, 0xb8, 0x01, 0, 0, 0, 0xa2 };
 
     int
-    checkcrc(void)
+    checkcrc (void)
     {
-	uint8_t crc = 0, i;
+        uint8_t crc = 0, i;
 
-	for (i = 0; i < sizeof serno / sizeof serno[0]; i++)
-	    crc = _crc_ibutton_update(crc, serno[i]);
+        for (i = 0; i < sizeof serno / sizeof serno[0]; i++)
+            crc = _crc_ibutton_update (crc, serno[i]);
 
-	return crc; // must be 0
+        return crc; // must be 0
     }
     \endcode
 */
@@ -80,8 +88,8 @@
 /** \ingroup util_crc
     Optimized CRC-16 calculation.
 
-    Polynomial: x^16 + x^15 + x^2 + 1 (0xa001)<br>
-    Initial value: 0xffff
+    Polynomial: x<sup>16</sup> + x<sup>15</sup> + x<sup>2</sup> + 1 (0xa001)<br>
+    Initial value: \c 0xffff
 
     This CRC is normally used in disk-drive controllers.
 
@@ -89,25 +97,22 @@
 
     \code
     uint16_t
-    crc16_update(uint16_t crc, uint8_t a)
+    crc16_update (uint16_t crc, uint8_t a)
     {
-	int i;
+        crc ^= a;
+        for (int i = 0; i < 8; ++i)
+        {
+            if (crc & 1)
+                crc = (crc >> 1) ^ 0xA001;
+            else
+                crc = crc >> 1;
+        }
 
-	crc ^= a;
-	for (i = 0; i < 8; ++i)
-	{
-	    if (crc & 1)
-		crc = (crc >> 1) ^ 0xA001;
-	    else
-		crc = (crc >> 1);
-	}
-
-	return crc;
+        return crc;
     }
-
     \endcode */
 
-static __inline__ uint16_t
+static __ATTR_ALWAYS_INLINE__ uint16_t
 _crc16_update(uint16_t __crc, uint8_t __data)
 {
 	uint8_t __tmp;
@@ -147,8 +152,8 @@ _crc16_update(uint16_t __crc, uint8_t __data)
 /** \ingroup util_crc
     Optimized CRC-XMODEM calculation.
 
-    Polynomial: x^16 + x^12 + x^5 + 1 (0x1021)<br>
-    Initial value: 0x0
+    Polynomial: x<sup>16</sup> + x<sup>12</sup> + x<sup>5</sup> + 1 (0x1021)<br>
+    Initial value: \c 0x0
 
     This is the CRC used by the Xmodem-CRC protocol.
 
@@ -158,10 +163,8 @@ _crc16_update(uint16_t __crc, uint8_t __data)
     uint16_t
     crc_xmodem_update (uint16_t crc, uint8_t data)
     {
-        int i;
-
         crc = crc ^ ((uint16_t)data << 8);
-        for (i=0; i<8; i++)
+        for (int i = 0; i < 8; i++)
         {
             if (crc & 0x8000)
                 crc = (crc << 1) ^ 0x1021;
@@ -173,8 +176,8 @@ _crc16_update(uint16_t __crc, uint8_t __data)
     }
     \endcode */
 
-static __inline__ uint16_t
-_crc_xmodem_update(uint16_t __crc, uint8_t __data)
+static __ATTR_ALWAYS_INLINE__ uint16_t
+_crc_xmodem_update (uint16_t __crc, uint8_t __data)
 {
     uint16_t __ret;             /* %B0:%A0 (alias for __crc) */
     uint8_t __tmp1;             /* %1 */
@@ -182,38 +185,27 @@ _crc_xmodem_update(uint16_t __crc, uint8_t __data)
                                 /* %3  __data */
 
     __asm__ __volatile__ (
-        "eor    %B0,%3"          "\n\t" /* crc.hi ^ data */
-        "mov    __tmp_reg__,%B0" "\n\t"
-        "swap   __tmp_reg__"     "\n\t" /* swap(crc.hi ^ data) */
-
-        /* Calculate the ret.lo of the CRC. */
-        "mov    %1,__tmp_reg__"  "\n\t"
-        "andi   %1,0x0f"         "\n\t"
-        "eor    %1,%B0"          "\n\t"
+        "eor    %B0,%3"          "\n\t"
+        "mov    %1,%A0"          "\n\t"
         "mov    %2,%B0"          "\n\t"
-        "eor    %2,__tmp_reg__"  "\n\t"
-        "lsl    %2"              "\n\t"
-        "andi   %2,0xe0"         "\n\t"
-        "eor    %1,%2"           "\n\t" /* __tmp1 is now ret.lo. */
 
-        /* Calculate the ret.hi of the CRC. */
-        "mov    %2,__tmp_reg__"  "\n\t"
+        "mov    %A0,%B0"         "\n\t"
+        "swap   %B0"             "\n\t"
+        "eor    %A0,%B0"         "\n\t"
+
+        "andi   %A0,0xf0"        "\n\t"
+        "andi   %B0,0x0f"        "\n\t"
+
+        "eor    %1,%A0"          "\n\t"
         "eor    %2,%B0"          "\n\t"
-        "andi   %2,0xf0"         "\n\t"
-        "lsr    %2"              "\n\t"
-        "mov    __tmp_reg__,%B0" "\n\t"
-        "lsl    __tmp_reg__"     "\n\t"
-        "rol    %2"              "\n\t"
-        "lsr    %B0"             "\n\t"
-        "lsr    %B0"             "\n\t"
-        "lsr    %B0"             "\n\t"
-        "andi   %B0,0x1f"        "\n\t"
-        "eor    %B0,%2"          "\n\t"
-        "eor    %B0,%A0"         "\n\t" /* ret.hi is now ready. */
-        "mov    %A0,%1"          "\n\t" /* ret.lo is now ready. */
-        : "=d" (__ret), "=d" (__tmp1), "=d" (__tmp2)
+
+        "lsl    %A0"             "\n\t"
+        "rol    %B0"             "\n\t"
+
+        "eor    %B0,%1"          "\n\t"
+        "eor    %A0,%2"
+        : "=d" (__ret), "=r" (__tmp1), "=r" (__tmp2)
         : "r" (__data), "0" (__crc)
-        : "r0"
     );
     return __ret;
 }
@@ -221,8 +213,8 @@ _crc_xmodem_update(uint16_t __crc, uint8_t __data)
 /** \ingroup util_crc
     Optimized CRC-CCITT calculation.
 
-    Polynomial: x^16 + x^12 + x^5 + 1 (0x8408)<br>
-    Initial value: 0xffff
+    Polynomial: x<sup>16</sup> + x<sup>12</sup> + x<sup>5</sup> + 1 (0x8408)<br>
+    Initial value: \c 0xffff
 
     This is the CRC used by PPP and IrDA.
 
@@ -242,12 +234,12 @@ _crc_xmodem_update(uint16_t __crc, uint8_t __data)
         data ^= lo8 (crc);
         data ^= data << 4;
 
-        return ((((uint16_t)data << 8) | hi8 (crc)) ^ (uint8_t)(data >> 4) 
+        return ((((uint16_t)data << 8) | hi8 (crc)) ^ (uint8_t)(data >> 4)
                 ^ ((uint16_t)data << 3));
     }
     \endcode */
 
-static __inline__ uint16_t
+static __ATTR_ALWAYS_INLINE__ uint16_t
 _crc_ccitt_update (uint16_t __crc, uint8_t __data)
 {
     uint16_t __ret;
@@ -287,8 +279,8 @@ _crc_ccitt_update (uint16_t __crc, uint8_t __data)
 /** \ingroup util_crc
     Optimized Dallas (now Maxim) iButton 8-bit CRC calculation.
 
-    Polynomial: x^8 + x^5 + x^4 + 1 (0x8C)<br>
-    Initial value: 0x0
+    Polynomial: x<sup>8</sup> + x<sup>5</sup> + x<sup>4</sup> + 1 (0x8C)<br>
+    Initial value: \c 0x0
 
     See http://www.maxim-ic.com/appnotes.cfm/appnote_number/27
 
@@ -296,40 +288,101 @@ _crc_ccitt_update (uint16_t __crc, uint8_t __data)
 
     \code
     uint8_t
-    _crc_ibutton_update(uint8_t crc, uint8_t data)
+    _crc_ibutton_update (uint8_t crc, uint8_t data)
     {
-	uint8_t i;
+        crc = crc ^ data;
+        for (uint8_t i = 0; i < 8; i++)
+        {
+            if (crc & 0x01)
+                crc = (crc >> 1) ^ 0x8C;
+            else
+                crc >>= 1;
+        }
 
-	crc = crc ^ data;
-	for (i = 0; i < 8; i++)
-	{
-	    if (crc & 0x01)
-	        crc = (crc >> 1) ^ 0x8C;
-	    else
-	        crc >>= 1;
-	}
-
-	return crc;
+        return crc;
     }
     \endcode
 */
 
-static __inline__ uint8_t
-_crc_ibutton_update(uint8_t __crc, uint8_t __data)
+static __ATTR_ALWAYS_INLINE__ uint8_t
+_crc_ibutton_update (uint8_t __crc, uint8_t __data)
 {
 	uint8_t __i, __pattern;
 	__asm__ __volatile__ (
-		"	eor	%0, %4" "\n\t"
-		"	ldi	%1, 8" "\n\t"
-		"	ldi	%2, 0x8C" "\n\t"
-		"1:	lsr	%0" "\n\t"
-		"	brcc	2f" "\n\t"
-		"	eor	%0, %2" "\n\t"
-		"2:	dec	%1" "\n\t"
-		"	brne	1b" "\n\t"
+		"eor	%0, %4"    "\n\t"
+		"ldi	%1, 8"     "\n\t"
+		"ldi	%2, 0x8C"  "\n"
+		"1:	lsr	%0"        "\n\t"
+		"brcc	2f"        "\n\t"
+		"eor	%0, %2"    "\n"
+		"2:	dec	%1"        "\n\t"
+		"brne	1b"
 		: "=r" (__crc), "=d" (__i), "=d" (__pattern)
 		: "0" (__crc), "r" (__data));
 	return __crc;
 }
 
+/** \ingroup util_crc
+    Optimized CRC-8-CCITT calculation.
+
+    Polynomial: x<sup>8</sup> + x<sup>2</sup> + x + 1 (0xE0)<br>
+
+    For use with simple CRC-8<br>
+    Initial value: 0x0
+
+    For use with CRC-8-ROHC<br>
+    Initial value: 0xff<br>
+    Reference: http://tools.ietf.org/html/rfc3095#section-5.9.1
+
+    For use with CRC-8-ATM/ITU<br>
+    Initial value: 0xff<br>
+    Final XOR value: 0x55<br>
+    Reference: http://www.itu.int/rec/T-REC-I.432.1-199902-I/en
+
+    The C equivalent has been originally written by Dave Hylands.
+    Assembly code is based on _crc_ibutton_update optimization.
+
+    The following is the equivalent functionality written in C.
+
+    \code
+    uint8_t
+    _crc8_ccitt_update (uint8_t inCrc, uint8_t inData)
+    {
+        uint8_t data = inCrc ^ inData;
+
+        for (int i = 0; i < 8; i++)
+        {
+            if ((data & 0x80) != 0)
+            {
+                data <<= 1;
+                data ^= 0x07;
+            }
+            else
+            {
+                data <<= 1;
+            }
+        }
+        return data;
+    }
+    \endcode
+*/
+
+static __ATTR_ALWAYS_INLINE__ uint8_t
+_crc8_ccitt_update(uint8_t __crc, uint8_t __data)
+{
+    uint8_t __i, __pattern;
+    __asm__ __volatile__ (
+        "eor    %0, %4"   "\n\t"
+        "ldi    %1, 8"    "\n\t"
+        "ldi    %2, 0x07" "\n"
+        "1:	lsl    %0"    "\n\t"
+        "brcc   2f"       "\n\t"
+        "eor    %0, %2"   "\n"
+        "2:	dec    %1"    "\n\t"
+        "brne   1b"
+        : "=r" (__crc), "=d" (__i), "=d" (__pattern)
+        : "0" (__crc), "r" (__data));
+    return __crc;
+}
+
 #endif /* _UTIL_CRC16_H_ */
