@@ -31,7 +31,7 @@
 */
 
 /* From: Id: printf_p_new.c,v 1.1.1.9 2002/10/15 20:10:28 joerg_wunsch Exp */
-/* $Id: vfprintf.c 2191 2010-11-05 13:45:57Z arcanum $ */
+/* $Id$ */
 
 #if !defined(__AVR_TINY__)
 
@@ -79,7 +79,7 @@
 	"lpm	%0,Z+	\n\t"			\
 	"sbrs	%2,%3	\n\t"			\
 	"ld	%0,Z+	"			\
-	: "=r" (__c),				\
+	: "=&r" (__c),				\
 	  "+z" (pnt)				\
 	: "r" (flag),				\
 	  "I" (ntz(mask))			\
@@ -90,7 +90,6 @@
 # define GETBYTE(flag, mask, pnt)	({	\
     unsigned char __c;				\
     asm (					\
-	"sbrc	%2,%3	\n\t"			\
 	"lpm		\n\t"			\
 	"sbrs	%2,%3	\n\t"			\
 	"ld	r0,Z	\n\t"			\
@@ -123,6 +122,7 @@
 #define FL_ALTLWR	0x20
 #define FL_NEGATIVE	0x40
 #define FL_LONG 	0x80
+#define FL_LONG_DOUBLE 	(__SIZEOF_LONG_DOUBLE__ != __SIZEOF_DOUBLE__ ? 0x08 : 0)
 
 ATTRIBUTE_CLIB_SECTION
 int
@@ -163,13 +163,20 @@ vfprintf (FILE * stream, const char *fmt, va_list ap)
 		flags |= FL_LONG;
 		continue;
 	    }
+	    if (c == 'L') {
+		flags |= FL_LONG_DOUBLE;
+		continue;
+	    }
 	    break;
 	}
 
 	/* Only a format character is valid.	*/
 
 	if (c && strchr_P (PSTR("EFGefg"), c)) {
-	    (void) va_arg (ap, double);
+            if (flags & FL_LONG_DOUBLE)
+                (void) va_arg (ap, long double);
+            else
+                (void) va_arg (ap, double);
 	    putc ('?', stream);
 	    continue;
 	}
@@ -219,7 +226,7 @@ vfprintf (FILE * stream, const char *fmt, va_list ap)
 		goto ultoa;
 	      case 'p':
 	        flags |= FL_ALT;
-		/* no break */
+		/* fallthrough */
 	      case 'x':
 		flags |= (FL_ALTHEX | FL_ALTLWR);
 	        base = 16;
@@ -282,6 +289,10 @@ vfprintf (FILE * stream, const char *fmt, va_list ap)
 #define FL_FLTEXP	FL_PREC
 #define	FL_FLTFIX	FL_LONG
 
+/* %Lf might not be the same like %f. */
+#define XFL_LONG	((__SIZEOF_LONG_DOUBLE__ != __SIZEOF_DOUBLE__) << 0)
+
+
 ATTRIBUTE_CLIB_SECTION
 int vfprintf (FILE * stream, const char *fmt, va_list ap)
 {
@@ -290,6 +301,7 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
     unsigned char width;
     unsigned char prec;
     unsigned char buf[11];	/* size for -1 in octal, without '\0'	*/
+    unsigned char xflags;
 
     stream->len = 0;
 
@@ -308,10 +320,12 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
 	    putc (c, stream);
 	}
 
+	if (XFL_LONG)
+	    xflags = 0;
 	flags = 0;
 	width = 0;
 	prec = 0;
-	
+
 	do {
 	    if (flags < FL_WIDTH) {
 		switch (c) {
@@ -354,10 +368,14 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
 		    flags |= FL_LONG;
 		    continue;
 		}
+		if (c == 'L') {
+		    xflags |= XFL_LONG;
+		    continue;
+		}
 		if (c == 'h')
 		    continue;
 	    }
-	    
+
 	    break;
 	} while ( (c = GETBYTE (stream->flags, __SPGM, fmt)) != 0);
 
@@ -367,7 +385,19 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
 # error
 #endif
 
-#if PRINTF_LEVEL >= PRINTF_FLT
+	/* We only support 32-bit floating point, hence if double is 64 bits
+	   wide, there is nothing to do here because ... will promote float
+	   to double.  */
+#if (PRINTF_LEVEL >= PRINTF_FLT) && (__SIZEOF_DOUBLE__ == __SIZEOF_FLOAT__)
+
+	if ((xflags & XFL_LONG)
+	    && ((c >= 'E' && c <= 'G') || (c >= 'e' && c <= 'g')))
+	{
+	    (void) va_arg (ap, long double);
+	    buf[0] = '?';
+	    goto buf_addr;
+	}
+
 	if (c >= 'E' && c <= 'G') {
 	    flags |= FL_FLTUPP;
 	    c += 'e' - 'E';
@@ -404,7 +434,7 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
 	    }
 	    exp = __ftoa_engine (va_arg(ap,double), (char *)buf, vtype, ndigs);
 	    vtype = buf[0];
-    
+
 	    sign = 0;
 	    if ((vtype & FTOA_MINUS) && !(vtype & FTOA_NAN))
 		sign = '-';
@@ -463,7 +493,7 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
 			   ? prec - exp : 0;	/* fractional part length  */
 		}
 	    }
-    
+
 	    /* Conversion result length, width := free space length	*/
 	    if (flags & FL_FLTFIX)
 		n = (exp>0 ? exp+1 : 1);
@@ -472,7 +502,7 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
 	    if (sign) n += 1;
 	    if (prec) n += prec + 1;
 	    width = width > n ? width - n : 0;
-    
+
 	    /* Output before first digit	*/
 	    if (!(flags & (FL_LPAD | FL_ZFILL))) {
 		while (width) {
@@ -487,7 +517,7 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
 		    width--;
 		}
 	    }
-    
+
 	    if (flags & FL_FLTFIX) {		/* 'f' format		*/
 
 		n = exp > 0 ? exp : 0;		/* exponent of left digit */
@@ -507,7 +537,7 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
 		    flags = '1';
 		}
 		putc (flags, stream);
-	
+
 	    } else {				/* 'e(E)' format	*/
 
 		/* mantissa	*/
@@ -540,9 +570,12 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
 # undef ndigs
 	}
 
-#else		/* to: PRINTF_LEVEL >= PRINTF_FLT */
+#else		/* to: PRINTF_LEVEL >= PRINTF_FLT && double == float */
 	if ((c >= 'E' && c <= 'G') || (c >= 'e' && c <= 'g')) {
-	    (void) va_arg (ap, double);
+	    if (xflags & XFL_LONG)
+		(void) va_arg (ap, long double);
+	    else
+		(void) va_arg (ap, double);
 	    buf[0] = '?';
 	    goto buf_addr;
 	}
@@ -557,9 +590,7 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
 
 	      case 'c':
 		buf[0] = va_arg (ap, int);
-#if  PRINTF_LEVEL < PRINTF_FLT
-	      buf_addr:
-#endif
+	      buf_addr: if (0) goto buf_addr;
 		pnt = (char *)buf;
 		size = 1;
 		goto no_pgmstring;
@@ -618,7 +649,7 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
 		goto ultoa;
 	      case 'p':
 	        flags |= FL_ALT;
-		/* no break */
+		/* fallthrough */
 	      case 'x':
 		if (flags & FL_ALT)
 		    flags |= FL_ALTHEX;
@@ -678,7 +709,7 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
 		    len++;
 		}
 	    }
-	
+
 	    width =  (len < width) ? width - len : 0;
 
 	    if (flags & FL_ALT) {
@@ -691,17 +722,17 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
 		if (flags & FL_NEGATIVE) z = '-';
 		putc (z, stream);
 	    }
-		
+
 	    while (prec > c) {
 		putc ('0', stream);
 		prec--;
 	    }
-	
+
 	    do {
 		putc (buf[--c], stream);
 	    } while (c);
 	}
-	
+
       tail:
 	/* Tail is possible.	*/
 	while (width) {
