@@ -30,7 +30,7 @@
   POSSIBILITY OF SUCH DAMAGE.
 */
 
-/* $Id: vfscanf.c 2191 2010-11-05 13:45:57Z arcanum $ */
+/* $Id$ */
 
 #if !defined(__AVR_TINY__)
 
@@ -129,7 +129,7 @@ typedef unsigned char width_t;
 	"lpm	%0,Z+	\n\t"			\
 	"sbrs	%2,%3	\n\t"			\
 	"ld	%0,Z+	"			\
-	: "=r" (__c),				\
+	: "=&r" (__c),				\
 	  "+z" (pnt)				\
 	: "r" (flag),				\
 	  "I" (_FFS(mask) - 1)			\
@@ -140,7 +140,6 @@ typedef unsigned char width_t;
 # define GETBYTE(flag, mask, pnt)	({	\
     unsigned char __c;				\
     asm (					\
-	"sbrc	%2,%3	\n\t"			\
 	"lpm		\n\t"			\
 	"sbrs	%2,%3	\n\t"			\
 	"ld	r0,Z	\n\t"			\
@@ -319,12 +318,12 @@ conv_brk (FILE *stream, width_t width, char *addr, const char *fmt)
     unsigned char frange;
     unsigned char cabove;
     int i;
-    
+
     memset (msk, 0, sizeof(msk));
     fnegate = 0;
     frange = 0;
     cabove = 0;			/* init to avoid compiler warning	*/
-    
+
     for (i = 0; ; i++) {
 	unsigned char c = GETBYTE(stream->flags, __SPGM, fmt);
 
@@ -340,9 +339,9 @@ conv_brk (FILE *stream, width_t width, char *addr, const char *fmt)
 		continue;
 	    }
 	}
-	
+
 	if (!frange) cabove = c;
-	
+
 	for (;;) {
 	    msk[c >> 3] |= 1 << (c & 7);
 	    if (c == cabove) break;
@@ -380,7 +379,7 @@ conv_brk (FILE *stream, width_t width, char *addr, const char *fmt)
 	if (addr) *addr++ = i;
 	fnegate = 0;
     } while (--width);
-    
+
     if (fnegate) {
 	return 0;
     } else {
@@ -396,17 +395,14 @@ conv_brk (FILE *stream, width_t width, char *addr, const char *fmt)
    long to float.  Instead it uses a signed long to float conversion
    function along with a large inline code to correct the result.
    Seems, GCC 4.3 does not use it also.	*/
-extern double __floatunsisf (unsigned long);
+extern float __floatunsisf (unsigned long);
 
-PROGMEM static const float pwr_p10 [6] = {
-    1e+1, 1e+2, 1e+4, 1e+8, 1e+16, 1e+32
-};
-PROGMEM static const float pwr_m10 [6] = {
-    1e-1, 1e-2, 1e-4, 1e-8, 1e-16, 1e-32
-};
+/* In libc/stdio/pwr_10.c */
+extern const float __avrlibc_pwr_p10 [6];
+extern const float __avrlibc_pwr_m10 [6];
 
-PROGMEM static const char pstr_nfinity[] = "nfinity";
-PROGMEM static const char pstr_an[] = "an";
+PROGMEM_FAR static const char pstr_nfinity[] = "nfinity";
+PROGMEM_FAR static const char pstr_an[] = "an";
 
 __attribute__((noinline))
 ATTRIBUTE_CLIB_SECTION
@@ -417,8 +413,12 @@ static unsigned char conv_flt (FILE *stream, width_t width, float *addr)
 	float flt;
     } x;
     int i;
-    const char *p;
     int exp;
+#ifndef __AVR_HAVE_ELPM__
+    const char *p;
+#else
+    uint_farptr_t pf;
+#endif
 
     unsigned char flag;
 #define FL_MINUS    0x80	/* number is negative	*/
@@ -441,6 +441,7 @@ static unsigned char conv_flt (FILE *stream, width_t width, float *addr)
 
     switch (tolower (i)) {
 
+#ifndef __AVR_HAVE_ELPM__
       case 'n':
 	p = pstr_an;
 	goto operate_pstr;
@@ -450,13 +451,13 @@ static unsigned char conv_flt (FILE *stream, width_t width, float *addr)
       operate_pstr:
         {
 	    unsigned char c;
-	    
+
 	    while ((c = pgm_read_byte (p++)) != 0) {
 		if (!--width
 		    || (i = getc (stream)) < 0
 		    || ((unsigned char)tolower(i) != c
 			&& (ungetc (i, stream), 1)))
-		{	
+		{
 		    if (p == pstr_nfinity + 3)
 			break;
 		    goto err;
@@ -466,13 +467,40 @@ static unsigned char conv_flt (FILE *stream, width_t width, float *addr)
 	x.flt = (p == pstr_an + 3) ? NAN : INFINITY;
 	break;
 
+#else /* ..ELPM.. */
+      case 'n':
+	pf = pgm_get_far_address (pstr_an[0]);
+	goto operate_pstr;
+
+      case 'i':
+	pf = pgm_get_far_address (pstr_nfinity[0]);
+      operate_pstr:
+        {
+	    uint8_t c;
+
+	    while ((c = pgm_read_u8_far (pf++)) != 0) {
+		if (!--width
+		    || (i = getc (stream)) < 0
+		    || ((uint8_t) tolower(i) != c
+			&& (ungetc (i, stream), 1)))
+		{
+		    if (pf == pgm_get_far_address (pstr_nfinity[3]))
+			break;
+		    goto err;
+		}
+	    }
+        }
+	x.flt = (pf == pgm_get_far_address (pstr_an[3])) ? NAN : INFINITY;
+	break;
+#endif /* ELPM ? */
+
       default:
         exp = 0;
 	x.u32 = 0;
 	do {
 
 	    unsigned char c = i - '0';
-    
+
 	    if (c <= 9) {
 		flag |= FL_ANY;
 		if (flag & FL_OVFL) {
@@ -492,10 +520,10 @@ static unsigned char conv_flt (FILE *stream, width_t width, float *addr)
 		break;
 	    }
 	} while (--width && (i = getc (stream)) >= 0);
-    
+
 	if (!(flag & FL_ANY))
 	    goto err;
-    
+
 	if ((unsigned char)i == 'e' || (unsigned char)i == 'E')
 	{
 	    int expacc;
@@ -522,26 +550,38 @@ static unsigned char conv_flt (FILE *stream, width_t width, float *addr)
 	}
 
 	if (width && i >= 0) ungetc (i, stream);
-    
+
 	x.flt = __floatunsisf (x.u32);
 
+#ifndef __AVR_HAVE_ELPM__
+	const float *f_pwr;
 	if (exp < 0) {
-	    p = (void *)(pwr_m10 + 5);
+	    f_pwr = __avrlibc_pwr_m10 + 5;
 	    exp = -exp;
 	} else {
-	    p = (void *)(pwr_p10 + 5);
+	    f_pwr = __avrlibc_pwr_p10 + 5;
 	}
 	for (width = 32; width; width >>= 1) {
 	    for (; (unsigned)exp >= width; exp -= width) {
-		union {
-		    long lo;
-		    float fl;
-		} y;
-		y.lo = pgm_read_dword (p);
-		x.flt *= y.fl;
+		x.flt *= pgm_read_float (f_pwr);
 	    }
-	    p = (void *)p - sizeof(float);
+	    --f_pwr;
 	}
+#else
+	uint_farptr_t f_pwr;
+	if (exp < 0) {
+	    f_pwr = pgm_get_far_address (__avrlibc_pwr_m10[5]);
+	    exp = -exp;
+	} else {
+	    f_pwr = pgm_get_far_address (__avrlibc_pwr_p10[5]);
+	}
+	for (width = 32; width; width >>= 1) {
+	    for (; (unsigned)exp >= width; exp -= width) {
+		x.flt *= pgm_read_float_far (f_pwr);
+	    }
+	    f_pwr -= sizeof (float);
+	}
+#endif /* ELPM ? */
     } /* switch */
 
     if (flag & FL_MINUS)
@@ -598,7 +638,7 @@ static int skip_spaces (FILE *stream)
      to <tt>char</tt> (rather than <tt>int</tt>).
    - the character \c l indicating that the argument is a pointer
      to <tt>long int</tt> (rather than <tt>int</tt>, for integer
-     type conversions), or a pointer to \c double (for floating
+     type conversions), or a pointer to \c float (for floating
      point conversions),
 
    In addition, a maximal field width may be specified as a nonzero
@@ -732,7 +772,7 @@ int vfscanf (FILE * stream, const char *fmt, va_list ap)
 		ungetc (i, stream);
 		break;
 	    }
-	
+
 	} else {
 	    flags = 0;
 
@@ -780,8 +820,14 @@ int vfscanf (FILE * stream, const char *fmt, va_list ap)
 # define CNV_FLOAT	""
 #endif
 #define CNV_LIST	CNV_BASE CNV_BRACKET CNV_FLOAT
+
+#ifndef __AVR_HAVE_ELPM__
 	    if (!c || !strchr_P (PSTR (CNV_LIST), c))
 		break;
+#else
+	    if (!c || !strchr_PF (PSTR_FAR (CNV_LIST), c))
+		break;
+#endif
 
 	    addr = (flags & FL_STAR) ? 0 : va_arg (ap, void *);
 
@@ -809,7 +855,7 @@ int vfscanf (FILE * stream, const char *fmt, va_list ap)
 
 		if (skip_spaces (stream) < 0)
 		    goto eof;
-		
+
 		switch (c) {
 
 		  case 's':
