@@ -28,7 +28,7 @@
    ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
    POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: strtod.c 2191 2010-11-05 13:45:57Z arcanum $ */
+/* $Id$ */
 
 
 #if !defined(__AVR_TINY__)
@@ -38,29 +38,39 @@
 #include <ctype.h>
 #include <errno.h>
 #include <limits.h>
-#include <math.h>		/* INFINITY, NAN		*/
+#include <math.h>
 #include <stdlib.h>
 #include "sectionname.h"
+#include "alias.h"
+
+
+#define INFINITYf (__builtin_inff())
+#define NANf      (__builtin_nanf(""))
+
+extern int isfinitef (float);
 
 /* Only GCC 4.2 calls the library function to convert an unsigned long
    to float.  Other GCC-es (including 4.3) use a signed long to float
    conversion along with a large inline code to correct the result.	*/
-extern double __floatunsisf (unsigned long);
+extern float __floatunsisf (unsigned long);
 
-PROGMEM static const float pwr_p10 [6] = {
-    1e+1, 1e+2, 1e+4, 1e+8, 1e+16, 1e+32
-};
-PROGMEM static const float pwr_m10 [6] = {
-    1e-1, 1e-2, 1e-4, 1e-8, 1e-16, 1e-32
-};
+#ifdef __AVR_HAVE_ELPM__
+#define STRNCASECMP_P(a, b, c) strncasecmp_PF (a, pgm_get_far_address(b), c)
+#else
+#define STRNCASECMP_P(a, b, c) strncasecmp_P (a, b, c)
+#endif
+
+/* In libc/stdio/pwr_10.c */
+extern const float __avrlibc_pwr_p10 [6];
+extern const float __avrlibc_pwr_m10 [6];
 
 /* PSTR() is not used to save 1 byte per string: '\0' at the tail.	*/
-PROGMEM static const char pstr_inf[] = {'I','N','F'};
-PROGMEM static const char pstr_inity[] = {'I','N','I','T','Y'};
-PROGMEM static const char pstr_nan[] = {'N','A','N'};
+PROGMEM_FAR static const char pstr_inf[] = {'I','N','F'};
+PROGMEM_FAR static const char pstr_inity[] = {'I','N','I','T','Y'};
+PROGMEM_FAR static const char pstr_nan[] = {'N','A','N'};
 
-/**  The strtod() function converts the initial portion of the string pointed
-     to by \a nptr to double representation.
+/**  The strtof() function converts the initial portion of the string pointed
+     to by \a nptr to \c float representation.
 
      The expected form of the string is an optional plus ( \c '+' ) or minus
      sign ( \c '-' ) followed by a sequence of digits optionally containing
@@ -70,7 +80,7 @@ PROGMEM static const char pstr_nan[] = {'N','A','N'};
 
      Leading white-space characters in the string are skipped.
 
-     The strtod() function returns the converted value, if any.
+     The strtof() function returns the converted value, if any.
 
      If \a endptr is not \c NULL, a pointer to the character after the last
      character used in the conversion is stored in the location referenced by
@@ -85,8 +95,8 @@ PROGMEM static const char pstr_nan[] = {'N','A','N'};
      returned and \c ERANGE is stored in \c errno.
  */
 ATTRIBUTE_CLIB_SECTION
-double
-strtod (const char * nptr, char ** endptr)
+float
+strtof (const char * nptr, char ** endptr)
 {
     union {
 	unsigned long u32;
@@ -116,30 +126,30 @@ strtod (const char * nptr, char ** endptr)
     } else if (c == '+') {
 	c = *nptr++;
     }
-    
-    if (!strncasecmp_P (nptr - 1, pstr_inf, 3)) {
+
+    if (!STRNCASECMP_P (nptr - 1, pstr_inf, 3)) {
 	nptr += 2;
-	if (!strncasecmp_P (nptr, pstr_inity, 5))
+	if (!STRNCASECMP_P (nptr, pstr_inity, 5))
 	    nptr += 5;
 	if (endptr)
 	    *endptr = (char *)nptr;
-	return flag & FL_MINUS ? -INFINITY : +INFINITY;
+	return flag & FL_MINUS ? -INFINITYf : +INFINITYf;
     }
-    
+
     /* NAN() construction is not realised.
        Length would be 3 characters only.	*/
-    if (!strncasecmp_P (nptr - 1, pstr_nan, 3)) {
+    if (!STRNCASECMP_P (nptr - 1, pstr_nan, 3)) {
 	if (endptr)
 	    *endptr = (char *)nptr + 2;
-	return NAN;
+	return NANf;
     }
 
     x.u32 = 0;
     exp = 0;
-    while (1) {
-    
+    while (1)
+    {
 	c -= '0';
-    
+
 	if (c <= 9) {
 	    flag |= FL_ANY;
 	    if (flag & FL_OVFL) {
@@ -161,7 +171,7 @@ strtod (const char * nptr, char ** endptr)
 	}
 	c = *nptr++;
     }
-    
+
     if (c == (('e'-'0') & 0xff) || c == (('E'-'0') & 0xff))
     {
 	int i;
@@ -190,38 +200,56 @@ strtod (const char * nptr, char ** endptr)
 	    exp += i;
 	}
     }
-    
+
     if ((flag & FL_ANY) && endptr)
 	*endptr = (char *)nptr - 1;
-    
+
     x.flt = __floatunsisf (x.u32);		/* manually	*/
     if ((flag & FL_MINUS) && (flag & FL_ANY))
 	x.flt = -x.flt;
-	
-    if (x.flt != 0) {
-	int pwr;
+
+    if (x.flt != 0)
+    {
+#ifndef __AVR_HAVE_ELPM__
+	const float *f_pwr;
 	if (exp < 0) {
-	    nptr = (void *)(pwr_m10 + 5);
+	    f_pwr = __avrlibc_pwr_m10 + 5;
 	    exp = -exp;
 	} else {
-	    nptr = (void *)(pwr_p10 + 5);
+	    f_pwr = __avrlibc_pwr_p10 + 5;
 	}
-	for (pwr = 32; pwr; pwr >>= 1) {
+	for (int pwr = 32; pwr; pwr >>= 1) {
 	    for (; exp >= pwr; exp -= pwr) {
-		union {
-		    unsigned long u32;
-		    float flt;
-		} y;
-		y.u32 = pgm_read_dword ((float *)nptr);
-		x.flt *= y.flt;
+		x.flt *= pgm_read_float (f_pwr);
 	    }
-	    nptr -= sizeof(float);
+	    --f_pwr;
 	}
-	if (!isfinite(x.flt) || x.flt == 0)
+#else
+	uint_farptr_t f_pwr;
+	if (exp < 0) {
+	    f_pwr = pgm_get_far_address (__avrlibc_pwr_m10[5]);
+	    exp = -exp;
+	} else {
+	    f_pwr = pgm_get_far_address (__avrlibc_pwr_p10[5]);
+	}
+	for (int pwr = 32; pwr; pwr >>= 1) {
+	    for (; exp >= pwr; exp -= pwr) {
+		x.flt *= pgm_read_float_far (f_pwr);
+	    }
+	    f_pwr -= sizeof (float);
+	}
+#endif /* ELPM ? */
+	if (!isfinitef(x.flt) || x.flt == 0)
 	    errno = ERANGE;
     }
 
     return x.flt;
 }
 
+DALIAS (strtof)
+double strtod (const char*, char**);
+
+LALIAS (strtof)
+long double strtold (const char*, char**);
+
 #endif
